Struct ContinuousAlleleFreqs

pub struct ContinuousAlleleFreqs {
    pub left_exclusive: bool,
    pub right_exclusive: bool,
    /* private fields */
}
An allele frequency range

Fields

left_exclusive: boolright_exclusive: bool

Implementations

Source

impl ContinuousAlleleFreqs

pub fn inclusive(range: Range<f64>) -> Self

create a left- and right-inclusive allele frequency range

pub fn exclusive(range: Range<f64>) -> Self

create a left- and right-exclusive allele frequency range

pub fn left_exclusive(range: Range<f64>) -> Self

create a left-exclusive allele frequency range

pub fn right_exclusive(range: Range<f64>) -> Self

create a right-exclusive allele frequency range

Methods from Deref<Target = Range<AlleleFreq>>

1.35.0 · Source

pub fn contains<U>(&self, item: &U) -> bool
where Idx: PartialOrd<U>, U: PartialOrd<Idx> + ?Sized,

Returns true if item is contained in the range.

Examples
assert!(!(3..5).contains(&2));
assert!( (3..5).contains(&3));
assert!( (3..5).contains(&4));
assert!(!(3..5).contains(&5));

assert!(!(3..3).contains(&3));
assert!(!(3..2).contains(&3));

assert!( (0.0..1.0).contains(&0.5));
assert!(!(0.0..1.0).contains(&f32::NAN));
assert!(!(0.0..f32::NAN).contains(&0.5));
assert!(!(f32::NAN..1.0).contains(&0.5));
1.47.0 · Source

pub fn is_empty(&self) -> bool

Returns true if the range contains no items.

Examples
assert!(!(3..5).is_empty());
assert!( (3..3).is_empty());
assert!( (3..2).is_empty());

The range is empty if either side is incomparable:

assert!(!(3.0..5.0).is_empty());
assert!( (3.0..f32::NAN).is_empty());
assert!( (f32::NAN..5.0).is_empty());